Module: Mandoc
- Defined in:
- lib/mandoc.rb,
lib/mandoc/version.rb,
ext/mandoc/rb_mandoc.c
Overview
-- Copyright (C) 2026 gemmaro
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details. ++
Defined Under Namespace
Classes: BlockNode, BodyNode, CommentNode, EQNNode, ElemNode, Error, HeadNode, ManMeta, MdocMeta, Meta, Node, Parser, RootNode, TBLNode, TailNode, TextNode
Constant Summary collapse
- VERSION =
"0.0.2"